# Generated by Django 3.2.7 on 2021-09-22 18:29

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Address',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False, unique=True, verbose_name='ID')),
                ('email', models.EmailField(max_length=254, verbose_name='Adresse électronique')),
                ('confirmed', models.BooleanField(default=False, verbose_name='Confirmé')),
            ],
        ),
    ]
