# Generated by Django 3.2.7 on 2021-09-13 09:41

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Sponsor',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=256, verbose_name='Nom')),
                ('logo', models.FileField(upload_to='', verbose_name='Logo')),
                ('enabled', models.BooleanField(verbose_name='Activé')),
                ('order', models.PositiveIntegerField(default=1, verbose_name='Ordre')),
            ],
            options={
                'ordering': ('order',),
            },
        ),
    ]
