# Generated by Django 3.2.7 on 2021-09-22 18:31

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('eventsd_newsletter', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='address',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name="Date d'inscription"),
            preserve_default=False,
        ),
    ]
