# Generated by Django 3.2.7 on 2021-09-22 17:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eventsd_sponsors', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='sponsor',
            name='description',
            field=models.TextField(blank=True, max_length=2000, null=True, verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='sponsor',
            name='featured',
            field=models.BooleanField(default=False, verbose_name='Mis en avant'),
        ),
        migrations.AddField(
            model_name='sponsor',
            name='website_url',
            field=models.URLField(blank=True, null=True, verbose_name='URL du site'),
        ),
    ]
